( cd usr/lib ; rm -rf libgimpprint.so.1 )
( cd usr/lib ; ln -sf libgimpprint.so.1.1.3 libgimpprint.so.1 )
( cd usr/lib ; rm -rf libgimpprint.so )
( cd usr/lib ; ln -sf libgimpprint.so.1.1.3 libgimpprint.so )
